public class jDJTSatLib
{
	//Establishes connection with COM object. Called when first instance is made
	private native boolean init();
	//Closes connection.  Called when last instance is closed
	private native void deinit();
	//Returns the library version information.
 	public native String getVersionString();
 	//The folder where two-line Kepler data is stored, setting causes the satellite list to be created from that data.
 	public native String getKeplerPath();
 	//The folder where two-line Kepler data is stored, setting causes the satellite list to be created from that data. 
 	public native void setKeplerPath(String arg);
 	public native int getSatCount();
 	//Comma-separated list of satellite names. 
 	public native String getSatNames();
 	// Observer latitude in degrees. 
 	public native double getObsLat();
 	// Observer latitude in degrees. 
 	public native void setObsLat(double arg);
 	//Observer longitude in degrees. 
 	public native double getObsLon();
 	//Observer longitude in degrees. 
 	public native void setObsLon(double arg);
 	//Observer height in metres. 
 	public native double getObsHeight();
 	//Observer height in metres. 
 	public native void setObsHeight(double arg);
 	//Returns comma separated list of passes, UTC Borland format date input. 
 	public native String PassListForPeriod(String Name, double UTCdate, int MinSeconds, int NumDays, double MinElevDegrees);
 	//True if the named satellite visible, time in Julian, angular results in radians. 
 	public native boolean IsVisible(String Name, double JulianTime, double ThresholdDeg, boolean[] Southbound, 
 		double[] Azumuth, double[] Elevation, double[] Longitude, double[] Latitude, double[] Range, 
 		double[] RangeRate, double[] Altitude, double[] Phase);
 	//Converts Borland format TDateTime to Julian Time. 
 	public native double DateTimeToJT(double DateTime);
 	//Revolution number for a satellite (immediately after IsVisible call). 
 	public native int getRevNumber();
 	//Radians past ascending node for a satellite (immediately after IsVisible call). 
 	public native double getOrbitPhase();
 	//Determine next AOS for satellite, -1 if > 2days away. 
 	public native double FindAOS(String Name, double PredictTime);
 	//Determine next AOS for satellite, -1 if > 2days away. 
 	public native double FindLOS(String Name, double PredictTime);
 	//Revolutions (immediately after IsVisible call). 
 	public native double getMeanAnomaly();
 	//Returns satellite position and velocity in km and km/sec. 
 	public native void SatState(double[] X, double[] Y,	double[] Z, 
 		double[] Xdot, double[] Ydot, double[] Zdot);
	//Orbital period for named satellite, in days. 
 	public native double Period(String Name);
 	//Returns Kepler data. 
 	public native void KeplerData(String Name, double[] JulianEpoch, 
 		double[] Inclination, double[] RAAN, double[] Eccentricity,	double[] ArgOfPerigee, 
 		double[] DecayRate, double[] Period, double[] MeanAnomaly);
 	//Returns comma-separated list of pass details for each step. 
 	public native String MakePassDetails(String PassDescription, int StepSeconds);
 	
 	private static boolean dllLoaded = false;
 	private static int refCount = 0;
 	private static String message1 = "Could not connect to DJTSatLib\n - Run 'REGSVR32 DJTSatLib.dll' from the command line";
 	private static String message2 = "jDJTSatLib.dll could not be loaded\n - Make sure that it is in your Java library path";
 	
 	public jDJTSatLib()
 		throws Exception
 	{
 		if (dllLoaded)
 		{
 			if (!init())
 				throw new Exception(message1);
 			refCount++;
 		}
 		else
 			throw new Exception(message2);
 	}
 	
// Specify the absolute path of the DLL. Ex : jDJTSatLib("C:/Java/wxTrack/")
 	public jDJTSatLib(String path)
 		throws Exception
 	{
 		if (!dllLoaded)
 			LoadDLL(path);
 		if (!init())
 			throw new Exception(message1);
 		refCount++;
 	}

 	public static boolean IsDLLLoaded()
 	{
 		return dllLoaded;
 	}

 	public static void LoadDLL(String path)
 		throws Exception
 	{
 		if (refCount == 0)
 		{
 			try
 			{
 				System.load(path+"/jDJTSatLib.dll");
 			}
 	    	catch(Exception ex)
 	    	{
 	    		throw new Exception(message2);
 	    	}
 	    	catch(Error err)
 	    	{
 	    		throw new Exception(message2);
 	    	}
 		}
 	}
 	
 	public void Close()
 	{
 		refCount--;
 		if (refCount == 0)
 			deinit();
 	}

    static
    {
    	try
    	{
    		System.loadLibrary("jDJTSatLib");
    		dllLoaded = true;
    	}
    	catch(Exception ex){}
    	catch(Error err){}
    	finally
    	{
    		try
    		{
    			System.load(System.getProperty("user.dir")+"/jDJTSatLib.dll");
    			dllLoaded = true;
    		}
    		catch(Exception ex){}
    	    catch(Error err){}
    	}
    }
}